@@ -4,10 +4,11 @@ package Moose::Meta::Role::Method;
 use strict;
 use warnings;
 
-our $VERSION   = '0.01';
+our $VERSION   = '0.68';
+$VERSION = eval $VERSION;
 our $AUTHORITY = 'cpan:STEVAN';
 
-use base 'Class::MOP::Method';
+use base 'Moose::Meta::Method';
 
 1;
 
@@ -23,7 +24,7 @@ Moose::Meta::Role::Method - A Moose Method metaclass for Roles
 
 This is primarily used to mark methods coming from a role 
 as being different. Right now it is nothing but a subclass
-of L<Class::MOP::Method>.
+of L<Moose::Meta::Method>.
 
 =head1 BUGS
 
@@ -37,11 +38,11 @@ Stevan Little E<lt>stevan@iinteractive.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006, 2007 by Infinity Interactive, Inc.
+Copyright 2006-2009 by Infinity Interactive, Inc.
 
 L<http://www.iinteractive.com>
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-=cut
\ No newline at end of file
+=cut
